==> boblogistics_0.15.6.zip: boblogistics_0.15.6/prototypes/item/roboport-parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "roboport-antenna-1",
    icon = "__boblogistics__/graphics/icons/roboport-antenna.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-antenna-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-2",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-antenna-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-3",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-antenna-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-4",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-antenna-4]",
    stack_size = 100
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "roboport-chargepad-1",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-chargepad-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-2",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-chargepad-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-3",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-chargepad-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-4",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-chargepad-4]",
    stack_size = 100
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "roboport-door-1",
    icon = "__boblogistics__/graphics/icons/roboport-door.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-door-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-2",
    icon = "__boblogistics__/graphics/icons/roboport-door-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-door-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-3",
    icon = "__boblogistics__/graphics/icons/roboport-door-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-door-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-4",
    icon = "__boblogistics__/graphics/icons/roboport-door-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-roboport-parts",
    order = "b[roboport-door-4]",
    stack_size = 100
  },
}
)

==> boblogistics_1.1.3.zip: boblogistics_1.1.3/prototypes/item/roboport-parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "roboport-antenna-1",
    icon = "__boblogistics__/graphics/icons/roboport-antenna.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-antenna",
    order = "b[roboport-antenna-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-2",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-2.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-antenna",
    order = "b[roboport-antenna-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-3",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-3.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-antenna",
    order = "b[roboport-antenna-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-antenna-4",
    icon = "__boblogistics__/graphics/icons/roboport-antenna-4.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-antenna",
    order = "b[roboport-antenna-4]",
    stack_size = 100
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "roboport-chargepad-1",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-charge",
    order = "b[roboport-chargepad-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-2",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-2.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-charge",
    order = "b[roboport-chargepad-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-3",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-3.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-charge",
    order = "b[roboport-chargepad-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-chargepad-4",
    icon = "__boblogistics__/graphics/icons/roboport-chargepad-4.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-charge",
    order = "b[roboport-chargepad-4]",
    stack_size = 100
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "roboport-door-1",
    icon = "__boblogistics__/graphics/icons/roboport-door.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-door",
    order = "b[roboport-door-1]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-2",
    icon = "__boblogistics__/graphics/icons/roboport-door-2.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-door",
    order = "b[roboport-door-2]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-3",
    icon = "__boblogistics__/graphics/icons/roboport-door-3.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-door",
    order = "b[roboport-door-3]",
    stack_size = 100
  },
  {
    type = "item",
    name = "roboport-door-4",
    icon = "__boblogistics__/graphics/icons/roboport-door-4.png",
    icon_size = 32,
    subgroup = "bob-roboport-parts-door",
    order = "b[roboport-door-4]",
    stack_size = 100
  },
}
)
